@@ -80,10 +80,30 @@ def params_table(
     if not os.path.isfile(params):
         raise IOError('`params` should be a JSON file.')
 
+    DISALLOWED_KEYS = {
+        "help",
+        "version",
+        "wf",
+        "aws_image_prefix",
+        "aws_queue",
+        "schema_ignore_params",
+        "show_hidden_params",
+        "monochrome_logs",
+        "validate_params",
+        "disable_ping",
+    }
+
     with open(params) as f:
         data = json.load(f)
-        params = [(k, v) for k, v in data.items()]
-        df_params = pd.DataFrame(params, columns=['Key', 'Value'])
+        filtered_params = {}
+        for k, v in data.items():
+            if k not in DISALLOWED_KEYS:
+                if isinstance(v, str) and v.startswith("s3://"):
+                    v = '/'.join(v.replace("s3://", "").split("/")[2:])
+                filtered_params[k] = v
+
+        filtered_params = [(k, v) for k, v in filtered_params.items()]
+        df_params = pd.DataFrame(filtered_params, columns=['Key', 'Value'])
         report.table(df_params, index=False, th_color=th_color)
         return report
 
